@@ -1,4 +1,9 @@
 from abc import abstractmethod
+from random import Random
+from typing import List
+
+from pyosmo.history.history import OsmoHistory
+from pyosmo.model import OsmoModelCollector, TestStep
 
 
 class OsmoAlgorithm:
@@ -8,7 +13,7 @@ class OsmoAlgorithm:
     def __init__(self):
         pass
 
-    def initialize(self, random, model):
+    def initialize(self, random: Random, model: OsmoModelCollector):
         """
         Initialize Osmo algorithm
         :param random: Used random
@@ -18,5 +23,5 @@ class OsmoAlgorithm:
         self.model = model
 
     @abstractmethod
-    def choose(self, history, choices):
+    def choose(self, history: OsmoHistory, choices: List[TestStep]) -> TestStep:
         raise Exception("This is just abstract class, not implementation")
