@@ -1,5 +1,8 @@
 from abc import abstractmethod
 
+from pyosmo.history.history import OsmoHistory
+from pyosmo.model import OsmoModelCollector
+
 
 class OsmoEndCondition:
     """
@@ -7,9 +10,9 @@ class OsmoEndCondition:
     """
 
     @abstractmethod
-    def end_test(self, history, model):
+    def end_test(self, history: OsmoHistory, model: OsmoModelCollector) -> bool:
         raise Exception("This is not implemented!")
 
     @abstractmethod
-    def end_suite(self, history, model):
+    def end_suite(self, history: OsmoHistory, model: OsmoModelCollector) -> bool:
         raise Exception("This is not implemented!")
