@@ -1,7 +1,8 @@
-import time
+from datetime import datetime, timedelta
 
-from pyosmo.history.test_case import TestCase
+from pyosmo.history.test_case import OsmoTestCaseRecord
 from pyosmo.history.test_step_log import TestStepLog
+from pyosmo.model import TestStep
 
 
 class OsmoHistory:
@@ -9,26 +10,26 @@ class OsmoHistory:
     def __init__(self):
         self.test_cases = []
         self.stop_time = None
-        self.start_time = time.time()
+        self.start_time = datetime.now()
 
     def start_new_test(self):
         # Stop test case timer
-        if self.current_test_case:
+        if self.current_test_case and self.current_test_case.is_running:
             self.current_test_case.stop()
         # Start a new test case
-        self.test_cases.append(TestCase())
+        self.test_cases.append(OsmoTestCaseRecord())
 
-    def stop(self):
+    def stop(self) -> None:
         if self.stop_time:
             return
         if self.current_test_case:
             self.current_test_case.stop()
-        self.stop_time = time.time()
+        self.stop_time = datetime.now()
 
-    def add_step(self, step, duration, error=None):
+    def add_step(self, step: TestStep, duration: timedelta, error: Exception = None):
         """ Add a step to the history """
         if self.current_test_case is None:
-            raise Exception("There is no current test case!!")
+            raise Exception("There is no active test case!!")
         self.current_test_case.add_step(TestStepLog(step, duration, error))
 
     @property
@@ -37,7 +38,7 @@ class OsmoHistory:
         return sum([x.error_count for x in self.test_cases])
 
     @property
-    def current_test_case(self):
+    def current_test_case(self) -> OsmoTestCaseRecord:
         """ The test case which is running or generating at the moment """
         return self.test_cases[-1] if self.test_cases else None
 
@@ -45,7 +46,7 @@ class OsmoHistory:
     def duration(self):
         if self.stop_time is None:
             # Test is still running
-            return time.time() - self.start_time
+            return datetime.now() - self.start_time
         return self.stop_time - self.start_time
 
     @property
@@ -56,9 +57,16 @@ class OsmoHistory:
     def total_amount_of_steps(self):
         return sum([len(tc.steps_log) for tc in self.test_cases])
 
-    def get_step_count(self, step):
+    def is_used(self, step: TestStep) -> bool:
+        """ is used at least once """
+        for tc in self.test_cases:
+            if tc.is_used(step):
+                return True
+        return False
+
+    def get_step_count(self, step: TestStep):
         """ Counts how many times the step is really called during whole history """
-        return sum([test_case.get_step_count(step) for test_case in self.test_cases])
+        return sum((test_case.get_step_count(step) for test_case in self.test_cases))
 
     @property
     def step_stats(self):
@@ -74,16 +82,15 @@ class OsmoHistory:
             ret += f'{key}:{value}\n'
         return ret
 
-    @property
-    def summary(self):
+    def print_summary(self):
         if self.stop_time is None:
             raise Exception("Cannot get summary of ongoing test")
-        ret = ''
-        ret += 'Osmo summary:\n'
+        ret = '\n'
+        ret += 'Osmo run summary:\n'
         ret += f'Test cases: {self.test_case_count}\n'
         ret += f'Test steps: {self.total_amount_of_steps}\n'
-        ret += f'Duration: {self.duration:.2f}s\n'
-        return ret
+        ret += f'Duration: {self.duration}\n'
+        print(ret)
 
     def __str__(self):
         ret = ''
