@@ -1,4 +1,5 @@
-import time
+from datetime import datetime
+from datetime import timedelta
 from random import randint
 
 import pytest
@@ -32,27 +33,27 @@ def test_length_end_condition(steps, tests):
 def test_test_time_end_condition():
     time_in_sec = 1
     osmo = Osmo(TempModel())
-    osmo.test_end_condition = Time(time_in_sec)
+    osmo.test_end_condition = Time(timedelta(seconds=time_in_sec))
     osmo.test_suite_end_condition = Length(1)
-    start_time = time.time()
+    start_time = datetime.now()
     osmo.generate()
-    end_time = time.time()
+    end_time = datetime.now()
     duration = end_time - start_time
-    assert duration < time_in_sec + 0.1
-    assert duration > time_in_sec - 0.1
+    assert duration < timedelta(seconds=time_in_sec + 0.1)
+    assert duration > timedelta(seconds=time_in_sec - 0.1)
 
 
 def test_test_suite_time_end_condition():
     time_in_sec = 1
     osmo = Osmo(TempModel())
     osmo.test_end_condition = Length(1)
-    osmo.test_suite_end_condition = Time(time_in_sec)
-    start_time = time.time()
+    osmo.test_suite_end_condition = Time(timedelta(seconds=time_in_sec))
+    start_time = datetime.now()
     osmo.generate()
-    end_time = time.time()
+    end_time = datetime.now()
     duration = end_time - start_time
-    assert duration < time_in_sec + 0.1
-    assert duration > time_in_sec - 0.1
+    assert duration < timedelta(seconds=time_in_sec + 0.1)
+    assert duration > timedelta(seconds=time_in_sec - 0.1)
 
 
 def test_logical_and():
